@@ -4,12 +4,8 @@ import codecs
 from glob import glob
 import logging
 import shutil
-from lxml import etree
-from tempfile import mkdtemp, mktemp
 from subprocess import check_output
 
-import networkx as nx
-
 def _sentiter(func):
     return lambda self: [func(self, sent) for sent in self._sents()]
 
@@ -107,7 +103,7 @@ class CoreNLPDoc(object):
     def collapsed_cc_deps(self, sent):
         return self._dparse(sent, dep_type='collapsed-ccprocessed-dependencies')
 
-def parse_texts(texts, jar_dir, prop_file=None):
+def parse_texts(texts, jar_dir, prop_file=None, keep_files=False):
     temp_dir = mkdtemp("corenlp")
     logging.debug("Creating temporary dir for input texts: {}".format(temp_dir))
     fnames = [mktemp(dir=temp_dir) for text in texts]
@@ -143,5 +139,8 @@ def parse_texts(texts, jar_dir, prop_file=None):
         return [CoreNLPDoc(c_file.encode('utf-8')) for c_file in cleaned_files]
 
     finally:
-        logging.debug("Cleaning up in temporary dir: {}".format(temp_dir))
-        shutil.rmtree(temp_dir)
\ No newline at end of file
+        if not keep_files:
+            logging.debug("Cleaning up in temporary dir: {}".format(temp_dir))
+            shutil.rmtree(temp_dir)
+        else:
+            logging.info("Not cleaning temporary dir: {}".format(temp_dir))
\ No newline at end of file
